==> S2.2.2.zip: seasar2/src/test/org/seasar/framework/util/UtilAllTests.java <==
package test.org.seasar.framework.util;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * @author higa
 *
 */
public class UtilAllTests {

	public static void main(String[] args) {
		junit.textui.TestRunner.run(UtilAllTests.class);
	}

	public static Test suite() {
		TestSuite suite =
			new TestSuite("Test for test.org.seasar.framework.util");
		//$JUnit-BEGIN$
		suite.addTest(new TestSuite(ArrayMapTest.class));
		suite.addTest(new TestSuite(ArrayUtilTest.class));
		suite.addTest(new TestSuite(Base64UtilTest.class));
		suite.addTest(new TestSuite(BooleanConversionUtilTest.class));
		suite.addTest(new TestSuite(ByteConversionUtilTest.class));
		suite.addTest(new TestSuite(CaseInsensitiveMapTest.class));
		suite.addTest(new TestSuite(CaseInsensitiveSetTest.class));
		suite.addTest(new TestSuite(ClassUtilTest.class));
		suite.addTest(new TestSuite(DatabaseMetaDataUtilTest.class));
		suite.addTest(new TestSuite(DecimalFormatSymbolsUtilTest.class));
		suite.addTest(new TestSuite(DomUtilTest.class));
		suite.addTest(new TestSuite(LikeUtilTest.class));
		suite.addTest(new TestSuite(LocaleUtilTest.class));
		suite.addTest(new TestSuite(LongConversionUtilTest.class));
		suite.addTest(new TestSuite(MathUtilTest.class));
		suite.addTest(new TestSuite(ResourceBundleUtilTest.class));
		suite.addTest(new TestSuite(ResourceUtilTest.class));
		suite.addTest(new TestSuite(SerializeUtilTest.class));
		suite.addTest(new TestSuite(SLinkedListTest.class));
		suite.addTest(new TestSuite(TextUtilTest.class));
		suite.addTest(new TestSuite(StringUtilTest.class));
		//$JUnit-END$
		return suite;
	}
}

==> S2.2.9.zip: seasar2/src/test/org/seasar/framework/util/UtilAllTests.java <==
package test.org.seasar.framework.util;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * @author higa
 *
 */
public class UtilAllTests {

	public static void main(String[] args) {
		junit.textui.TestRunner.run(suite());
	}

	public static Test suite() {
		TestSuite suite =
			new TestSuite("Test for test.org.seasar.framework.util");
		//$JUnit-BEGIN$
		suite.addTest(new TestSuite(ArrayMapTest.class));
		suite.addTest(new TestSuite(ArrayUtilTest.class));
		suite.addTest(new TestSuite(Base64UtilTest.class));
		suite.addTest(new TestSuite(BooleanConversionUtilTest.class));
		suite.addTest(new TestSuite(ByteConversionUtilTest.class));
		suite.addTest(new TestSuite(CaseInsensitiveMapTest.class));
		suite.addTest(new TestSuite(CaseInsensitiveSetTest.class));
		suite.addTest(new TestSuite(ClassUtilTest.class));
		suite.addTest(new TestSuite(DatabaseMetaDataUtilTest.class));
		suite.addTest(new TestSuite(DecimalFormatSymbolsUtilTest.class));
		suite.addTest(new TestSuite(DomUtilTest.class));
		suite.addTest(new TestSuite(LikeUtilTest.class));
		suite.addTest(new TestSuite(LocaleUtilTest.class));
		suite.addTest(new TestSuite(LongConversionUtilTest.class));
		suite.addTest(new TestSuite(MathUtilTest.class));
		suite.addTest(new TestSuite(ResourceBundleUtilTest.class));
		suite.addTest(new TestSuite(ResourceUtilTest.class));
		suite.addTest(new TestSuite(SerializeUtilTest.class));
		suite.addTest(new TestSuite(SLinkedListTest.class));
		suite.addTest(new TestSuite(TextUtilTest.class));
		suite.addTest(new TestSuite(StringUtilTest.class));
		//$JUnit-END$
		return suite;
	}
}
